@@ -1,4 +1,4 @@
 """ Core specifications for Maggma """
-from maggma.core.validator import Validator
-from maggma.core.store import Store, Sort, DateTimeFormat, StoreError
 from maggma.core.builder import Builder
+from maggma.core.store import DateTimeFormat, Sort, Store, StoreError
+from maggma.core.validator import Validator
