@@ -6,6 +6,7 @@ various utilities
 """
 
 import json
+import yaml
 from itertools import chain, groupby
 from socket import socket
 from typing import Any, Dict, Iterator, List, Optional, Tuple, Union
@@ -165,7 +166,7 @@ class MongoStore(Store):
         return hash((self.database, self.collection_name, self.last_updated_field))
 
     @classmethod
-    def from_db_file(cls, filename: str):
+    def from_db_file(cls, filename: str, **kwargs):
         """
         Convenience method to construct MongoStore from db_file
         from old QueryEngine format
@@ -177,6 +178,27 @@ class MongoStore(Store):
         kwargs.pop("aliases", None)
         return cls(**kwargs)
 
+    @classmethod
+    def from_launchpad_file(cls, lp_file, collection_name, **kwargs):
+        """
+        Convenience method to construct MongoStore from a launchpad file
+
+        Note: A launchpad file is a special formatted yaml file used in fireworks
+
+        Returns:
+        """
+        with open(lp_file, 'r') as f:
+            lp_creds = yaml.load(f, Loader=None)
+
+        db_creds = lp_creds.copy()
+        db_creds['database'] = db_creds['name']
+        for key in list(db_creds.keys()):
+            if key not in ['database', 'host', 'port', 'username', 'password']:
+                db_creds.pop(key)
+        db_creds['collection_name'] = collection_name
+
+        return cls(**db_creds, **kwargs)
+
     def distinct(
         self, field: str, criteria: Optional[Dict] = None, all_exist: bool = False
     ) -> List:
