@@ -19,6 +19,12 @@ def db_json(test_dir):
     return db_json.resolve()
 
 
+@pytest.fixture
+def lp_file(test_dir):
+    db_dir = test_dir / "settings_files"
+    lp_file = db_dir / "my_launchpad.yaml"
+    return lp_file.resolve()
+
 @pytest.fixture
 def log_to_stdout():
     # Set Logging
